@@ -183,7 +183,7 @@ class Handler(tornado.web.RequestHandler):
     def get(self):
         self.write("<pre>")
         for job in self.application.done:
-            self.write("%25s %25s %25s\n" % (job.branch, job.event, job.status))
+            self.write("%25s %25s %25s %25s\n" % (job.branch, job.event, job.status, job.actor))
         self.write("</pre>")
 
     def post(self):
